#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-lua
version:              1.1.1.1
visibility:           public
id:                   tasty-lua-1.1.1.1-CCZbc5crGxSCSW4nT8swxq
key:                  tasty-lua-1.1.1.1-CCZbc5crGxSCSW4nT8swxq
license:              MIT
copyright:            © 2019-2025 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  b7af69a15e419358ac3dd95898ee8cf0
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.1.1.1-CCZbc5crGxSCSW4nT8swxq
depends:
    QuickCheck-2.15.0.1-uWFhBSX0xs6KM4Lxmzxul base-4.18.2.1
    bytestring-0.11.5.3 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    hslua-core-2.3.2-EOOdQy6J16X5edEyG7cwA3
    hslua-marshalling-2.3.1-JeINcJiyNiO9Dd0Lo32ezW
    lua-arbitrary-1.0.1.2-9zr8o7cvj7IJy2hsjM6Bkh
    tasty-1.5.3-CN8BxUi09UWAkVA7X0ZEf

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

